package WWW::WuFoo::WebHook;
{
  $WWW::WuFoo::WebHook::VERSION = '0.006';
}

use Moose;

# ABSTRACT: The WebHooks API is designed to help you inject a web hook into your user’s form. We believe this API will help reduce the friction your users experience integrating with your site. Let’s compare the steps your user would have to go through to set up a traditional site-to-site web hook integration to a Web Hook set up through the API.




1;
